@@ -1047,7 +1047,7 @@ for (;;)
           user_name = "";
           sender_local = FALSE;
           if (filter_test != NULL)
-            printf("Sender from \"From\" line: %s\n", sender_address);
+            printf("Sender taken from \"From\" line\n");
           }
         }
       }
