@@ -197,7 +197,7 @@ if ((smtp_accept_max_per_host > 0) &&
   {
   int i;
   int host_accept_count = 0;
-  int other_host_count = 0;    /* keep a count of non matches to optomise */
+  int other_host_count = 0;    /* keep a count of non matches to optimise */
 
   for (i = 0; i < smtp_accept_max; ++i)
     {
