@@ -18,6 +18,8 @@ optionlist smartuser_director_options[] = {
       (void *)(offsetof(smartuser_director_options_block, new_address)) },
   { "panic_expansion_fail", opt_bool,
       (void *)(offsetof(smartuser_director_options_block, panic_expansion_fail)) },
+  { "qualify_preserve_domain", opt_bool,
+      (void *)(offsetof(smartuser_director_options_block, qualify_preserve_domain)) },
   { "rewrite",              opt_bool,
       (void *)(offsetof(smartuser_director_options_block, rewrite)) }
 };
@@ -53,6 +55,7 @@ smartuser_director_options_block smartuser_director_option_defaults = {
   /********************************************/
   NULL,     /* new_address */
   TRUE,     /* panic_expansion_fail */
+  FALSE,    /* qualify_preserve_domain */
   TRUE      /* rewrite */
 };
 
@@ -261,10 +264,16 @@ if (transport != NULL)
 
 /* When there is no transport, use the common extraction function to extract
 one or more new addresses from the expanded string, as for forwarding and
-aliasing directors. */
+aliasing directors. If qualify_preserve_domain is set, we temporarily reset the
+value of qualify_domain_recipient to the current domain, so that any
+unqualified addresses get qualified with the same domain as the incoming
+address. */
 
 else
   {
+  char *save_qualify_domain_recipient = qualify_domain_recipient;
+
+  if (ob->qualify_preserve_domain) qualify_domain_recipient = addr->domain;
   extracted = parse_extract_addresses(raw_new_address, addr->domain, &generated,
     &error,
     FALSE,        /* No addresses is an error */
@@ -273,6 +282,7 @@ else
     "*",          /* No :include: files permitted */
     NULL          /* Syntax errors are serious */
     );
+  qualify_domain_recipient = save_qualify_domain_recipient;
 
   /* Cases of extraction failure are also handled by a common function. */
 
