@@ -3016,6 +3016,18 @@ while (more)
     deliver_localpart_suffix = ftest_suffix;
     deliver_home = getenv("HOME");
     if (return_path == NULL) return_path = string_copy(sender_address);
+
+    printf("Sender    = %s\n", (sender_address[0] == 0)? "<>" : sender_address);
+    printf("Recipient = %s%s%s@%s\n",
+      (ftest_prefix == NULL)? "" : ftest_prefix,
+      deliver_localpart,
+      (ftest_suffix == NULL)? "" : ftest_suffix,
+      deliver_domain);
+    if (ftest_prefix != NULL) printf("Prefix    = %s\n", ftest_prefix);
+    if (ftest_suffix != NULL) printf("Suffix    = %s\n", ftest_suffix);
+
+    printf("Testing Exim filter file %s\n\n", filter_test);
+
     exit(filter_runtest(filter_fd, ftest_system, more)?
       EXIT_SUCCESS : EXIT_FAILURE);
     }
