@@ -246,6 +246,15 @@ use different values for specific OS if ever necessary. */
 #define S_ADDR_TYPE u_long
 #endif
 
+/* (At least) one operating system (Solaris) defines a different type for the
+second argument of pam_converse() - the difference is the absence of "const".
+Its os.h file defines PAM_CONVERSE_ARG2_TYPE. For the rest, define a default
+here. */
+
+#ifndef PAM_CONVERSE_ARG2_TYPE
+#define PAM_CONVERSE_ARG2_TYPE const struct pam_message
+#endif
+
 /* One operating system (SunOS4) defines getc, ungetc, feof, and ferror as
 macros and not as functions. Exim needs them to be assignable functions. This
 flag gets set to cause this to be sorted out here. */
