@@ -43,6 +43,7 @@ int arg = 1;
 int add_zero = 1;
 BOOL lowercase = TRUE;
 BOOL warn = TRUE;
+BOOL duperr = TRUE;
 BOOL lastdup = FALSE;
 #ifndef USE_DB
 int is_db = 0;
@@ -60,10 +61,11 @@ char *line = malloc(maxsize);
 
 while (argc > 1)
   {
-  if      (strcmp(argv[arg], "-nolc") == 0)    lowercase = FALSE;
-  else if (strcmp(argv[arg], "-nowarn") == 0)  warn = FALSE;
-  else if (strcmp(argv[arg], "-lastdup") == 0) lastdup = TRUE;
-  else if (strcmp(argv[arg], "-nozero") == 0)  add_zero = 0;
+  if      (strcmp(argv[arg], "-nolc") == 0)     lowercase = FALSE;
+  else if (strcmp(argv[arg], "-nowarn") == 0)   warn = FALSE;
+  else if (strcmp(argv[arg], "-lastdup") == 0)  lastdup = TRUE;
+  else if (strcmp(argv[arg], "-noduperr") == 0) duperr = FALSE;
+  else if (strcmp(argv[arg], "-nozero") == 0)   add_zero = 0;
   else break;
   arg++;
   argc--;
@@ -180,7 +182,7 @@ while (fgets(line, maxsize, f) != NULL)
         if (warn) fprintf(stderr, "** Duplicate key \"%s\"\n",
           keybuffer);
         dupcount++;
-        yield = 1;
+        if(duperr) yield = 1;
         if (lastdup) EXIM_DBPUT(d, key, content);
         break;
 
@@ -257,7 +259,7 @@ if (started)
     case EXIM_DBPUTB_DUP:
     if (warn) fprintf(stderr, "** Duplicate key \"%s\"\n", keybuffer);
     dupcount++;
-    yield = 1;
+    if (duperr) yield = 1;
     if (lastdup) EXIM_DBPUT(d, key, content);
     break;
 
