@@ -651,7 +651,7 @@ header_line *h;
 
 for (h = header_list; h != NULL && size < 64 * 1024; h = h->next)
   {
-  if (h->type != htype_old)
+  if (h->type != htype_old && h->text != NULL)  /* NULL => Received: placeholder */
     {
     if (len <= h->slen && strncmpic(name, h->text, len) == 0)
       {
@@ -784,7 +784,7 @@ if (strcmp(name, "def") == 0 && *s == ':')
 
 else if (strcmp(name, "first_delivery") == 0)
   {
-  *yield = deliver_firsttime == testfor;
+  if (yield != NULL) *yield = deliver_firsttime == testfor;
   return s;
   }
 
@@ -792,7 +792,7 @@ else if (strcmp(name, "first_delivery") == 0)
 
 else if (strcmp(name, "queue_running") == 0)
   {
-  *yield = (queue_run_pid != (pid_t)0) == testfor;
+  if (yield != NULL) *yield = (queue_run_pid != (pid_t)0) == testfor;
   return s;
   }
 
@@ -819,7 +819,7 @@ else if (strcmp(name, "exists") == 0
     if (name[0] == 'p')
       {
       int rc = auth_call_pam(sub, &expand_string_message);
-      if (rc == ERROR) return s;
+      if (rc == ERROR) return NULL;
       *yield = (rc == OK) == testfor;
       }
     else
@@ -2055,6 +2055,7 @@ while (*s != 0)
           for (i = 0; i < value1; i++)
             sub[i] = hashcodes[(uschar)(sub[i]) % value2];
           }
+        else value1 = sublen;
 
         yield = string_cat(yield, &size, &ptr, sub, value1);
         continue;
