@@ -930,8 +930,9 @@ switch (command)
       {
       if (!system_filtering)
         {
-        *error_pointer = string_sprintf("unavailable filtering command \"%s\" "
-          "near line %d of filter file", command_list[command], line_number);
+        *error_pointer = string_sprintf("filtering command \"%s\" is "
+          "available only in system filters: near line %d of filter file",
+          command_list[command], line_number);
         yield = FALSE;
         break;
         }
@@ -1040,8 +1041,9 @@ switch (command)
   case freeze_command:
   if (special_action == NULL)
     {
-    *error_pointer = string_sprintf("unavailable filtering command \"%s\" "
-      "near line %d of filter file", buffer, line_number);
+    *error_pointer = string_sprintf("filtering command \"%s\" is available "
+      "only in system filters: near line %d of filter file", buffer,
+      line_number);
     yield = FALSE;
     break;
     }
@@ -2534,8 +2536,6 @@ char *body, *error, *filebuf, *s, *tag;
 /* Read the filter file into store as will be done by the director
 in a real case. */
 
-debug_printf("Testing Exim filter file %s\n", filter_test);
-
 if (fstat(fd, &statbuf) != 0)
   {
   printf("exim: failed to get size of %s: %s\n", filter_test, strerror(errno));
