@@ -253,23 +253,34 @@ int
 host_self_action(address_item *addr, host_item *host, int code, BOOL rewrite,
   char *new)
 {
-char *format, *msg;
-
-if (host->mx >= 0)
-  {
-  format = "lowest MX record for %s points to local host";
-  msg = "lowest numbered MX record points to local host";
-  }
-else
-  {
-  format = "remote host address for %s is the local host";
-  msg = "remote host address is the local host";
-  }
+char *msg = (host->mx >= 0)?
+  "lowest numbered MX record points to local host" :
+  "remote host address is the local host";
 
 switch (code)
   {
   case self_freeze:
-  log_write(0, LOG_MAIN, format, addr->route_domain);
+
+  /* If there is no message id, this is happening during an address
+  verification, so give information about the address that is being verified,
+  and where it has come from. Otherwise, during message delivery, the normal
+  logging for the address will be sufficient. */
+
+  if (message_id[0] == 0)
+    {
+    if (sender_fullhost == NULL)
+      {
+      log_write(0, LOG_MAIN, "%s: %s (while routing <%s>)", msg,
+        addr->route_domain, addr->orig);
+      }
+    else
+      {
+      log_write(0, LOG_MAIN, "%s: %s (while verifying <%s> from host %s)",
+        msg, addr->route_domain, addr->orig, sender_fullhost);
+      }
+    }
+  else
+    log_write(0, LOG_MAIN, "%s: %s", msg, addr->route_domain);
   addr->message = msg;
   addr->special_action = SPECIAL_FREEZE;
   return ERROR;
@@ -281,7 +292,7 @@ switch (code)
   case self_local:
   DEBUG(2)
     {
-    debug_printf(format, addr->route_domain);
+    debug_printf("%s: %s", msg, addr->route_domain);
     debug_printf("\n  address passed to directors: self_host = %s\n",
       host->name);
     }
@@ -292,7 +303,7 @@ switch (code)
   case self_reroute:
   DEBUG(2)
     {
-    debug_printf(format, addr->route_domain);
+    debug_printf("%s: %s", msg, addr->route_domain);
     debug_printf(": domain changed to %s\n", new);
     }
   addr->route_domain = string_copy(new);
@@ -302,7 +313,7 @@ switch (code)
   case self_send:
   DEBUG(2)
     {
-    debug_printf(format, addr->route_domain);
+    debug_printf("%s: %s", msg, addr->route_domain);
     debug_printf(": configured to try delivery anyway\n");
     }
   return OK;
@@ -310,7 +321,7 @@ switch (code)
   case self_fail:    /* This is soft failure; pass to next router */
   DEBUG(2)
     {
-    debug_printf(format, addr->route_domain);
+    debug_printf("%s: %s", msg, addr->route_domain);
     debug_printf(": router failed soft\n");
     }
   addr->message = msg;
@@ -320,7 +331,7 @@ switch (code)
   case self_forcefail:
   DEBUG(2)
     {
-    debug_printf(format, addr->route_domain);
+    debug_printf("%s: %s", msg, addr->route_domain);
     debug_printf(": router failed hard\n");
     }
   addr->message = msg;
@@ -1358,6 +1369,7 @@ set_address_from_dns(host_item *host, char **fully_qualified_name)
 {
 dns_record *rr;
 host_item *last = NULL;
+BOOL first_find_again = FALSE;
 int i, rc, type;
 
 /* On an IPv6 system, go round the loop twice, looking for AAAA records
@@ -1379,11 +1391,31 @@ type = T_A;
 for (; i >= 0; type = T_A, i--)
   {
   rc = dns_lookup(host->name, type, fully_qualified_name);
-  if (rc == DNS_AGAIN || rc == DNS_FAIL) return HOST_FIND_AGAIN;
-  if (rc == DNS_NOMATCH) continue;
 
-  /* Fill in the given host item with the first address found; create
-  additional items for any others. */
+  /* We want to return HOST_FIND_AGAIN if either of the A or AAAA records
+  fails or times out, but not if the other one succeeds. (In the early
+  IPv6 days there are nameservers that always fail on AAAA, but are happy
+  to give out an A record. We want to proceed with that A record.) */
+
+  if (rc != DNS_SUCCEED)
+    {
+    if (i == 0)  /* Tried for an A record */
+      {
+      if (host->address != NULL) return HOST_FOUND;  /* AAAA was found */
+      if (rc == DNS_AGAIN || rc == DNS_FAIL || first_find_again)
+        return HOST_FIND_AGAIN;
+      return HOST_FIND_FAILED;
+      }
+
+    /* Tried for an AAAA record: remember the failure type, and loop to
+    look for an A record. */
+
+    if (rc != DNS_NOMATCH) first_find_again = TRUE;
+    continue;
+    }
+
+  /* Lookup succeeded: fill in the given host item with the first address
+  found; create additional items for any others. */
 
   for (rr = dns_next_rr(RESET_ANSWERS); rr != NULL;
        rr = dns_next_rr(RESET_NEXT))
@@ -1442,10 +1474,9 @@ for (; i >= 0; type = T_A, i--)
     }
   }
 
-/* If we found at least one A or AAAA record, the host->address field will
-have been filled in. */
+/* Control gets here only if the second lookup (the A record) succeeded. */
 
-return (host->address == NULL)? HOST_FIND_FAILED : HOST_FOUND;
+return HOST_FOUND;
 }
 
 
@@ -1799,6 +1830,7 @@ for (rr = dns_next_rr(RESET_ADDITIONAL); rr != NULL;
   DNS_NEXT_RR: continue;
   }
 
+
 /* Set the default yield to failure */
 
 yield = HOST_FIND_FAILED;
