@@ -489,7 +489,7 @@ DEBUG(9) debug_printf("LDAP parameters: user=%s pass=%s size=%d time=%d\n",
 
 /* No default servers, or URL contains a server name */
 
-if (ldap_default_servers == NULL || strncmpic(ldap_url, "ldap:///", 8) != 0)
+if (ldap_default_servers == NULL || strncmpic(url, "ldap:///", 8) != 0)
   {
   return perform_ldap_search(url, NULL, 0, single, res, errmsg, &defer_break,
     user, password, sizelimit, timelimit);
