@@ -1000,7 +1000,7 @@ return endyield;
 *************************************************/
 
 /* This function is given a colon-separated list to be matched against the
-sender of the message. The list is first expanded. The address
+sender of the message.
 
 Argument:
   s          a colon-separated list (after expansion)
@@ -1014,23 +1014,14 @@ int
 match_sender(char *s)
 {
 BOOL yield;
-char *ss;
 char *address = (sender_address == NULL)? "" : sender_address;
 
 if (s == NULL) return FAIL;
 
-ss = expand_string(s);
-if (ss == NULL)
-  {
-  if (search_find_defer) return DEFER;
-  log_write(0, LOG_MAIN|LOG_PANIC_DIE, "expansion of %s failed: %s", s,
-    expand_string_message);
-  }
-
 yield = match_address_list(
   address,
   (address[0] == 0)? 0 : strchr(address, '@') - address + 1,
-  &ss,
+  &s,
   FALSE,
   ':',
   FALSE);
