@@ -416,7 +416,7 @@ char *subkey = NULL;
 char *colon = NULL;
 
 *errmsg = "";              /* indicates no error, or ordinary failed to find */
-search_find_defer = FALSE; /* NULL => not found */
+search_find_defer = FALSE;
 
 /* If there's a colon in a key for a single-key+file lookup, temporarily
 terminate the main key, and set up the subkey. */
