@@ -70,10 +70,8 @@ lock_data.l_whence = lock_data.l_start = lock_data.l_len = 0;
 
 if (fcntl(deliver_datafile, F_SETLK, &lock_data) < 0)
   {
-  if (message_id[0] == 0 || strcmp(message_id, id) != 0)
-    log_write(5, LOG_MAIN, "Spool file %s-D is locked", id);
-  else
-    log_write(5, LOG_MAIN, "Spool file is locked");
+  log_write(5, LOG_MAIN,
+    "Spool file is locked (another process is handling this message)");
   close(deliver_datafile);
   deliver_datafile = -1;
   errno = 0;
