@@ -45,6 +45,8 @@ optionlist appendfile_transport_options[] = {
 #endif
   { "*set_user",         opt_bool | opt_hidden | opt_public,
       (void *)(offsetof(transport_instance, uid_set)) },
+  { "allow_fifo",        opt_bool,
+      (void *)(offsetof(appendfile_transport_options_block, allow_fifo)) },
   { "allow_symlink",     opt_bool,
       (void *)(offsetof(appendfile_transport_options_block, allow_symlink)) },
   { "batch",             opt_local_batch | opt_public,
@@ -180,6 +182,7 @@ appendfile_transport_options_block appendfile_transport_option_defaults = {
   10,             /* maildir_retries */
   create_anywhere,/* create_file */
   0,              /* options */
+  FALSE,          /* allow_fifo */
   FALSE,          /* allow_symlink */
   FALSE,          /* check_group */
   TRUE,           /* create_directory */
@@ -799,9 +802,9 @@ directory name) is given:
      If it is a symbolic link AND the allow_symlink option is set (NOT the
      default), go back to (5f) but this time use stat() instead of lstat().
 
-     If it's not a regular file, complain to local administrator and defer
-     delivery with a local error code that causes subsequent delivery to
-     be prevented until manually enabled.
+     If it's not a regular file (or FIFO when permitted), complain to local
+     administrator and defer delivery with a local error code that causes
+     subsequent delivery to be prevented until manually enabled.
 
      Check permissions. If the required permissions are *less* than the
      existing ones, or supplied by the address (often by the user via filter),
@@ -818,7 +821,7 @@ directory name) is given:
      Check the inode number hasn't changed - I realize this isn't perfect (an
      inode can be reused) but it's cheap and will catch some of the races.
 
-     Check it's still a regular file.
+     Check it's still a regular file (or FIFO if permitted).
 
      Check that the owner and permissions haven't changed.
 
@@ -1486,6 +1489,7 @@ if (!isdirectory)
       int oldmode = (int)statbuf.st_mode;
       int inode = statbuf.st_ino;
       BOOL islink = (oldmode & S_IFMT) == S_IFLNK;
+      BOOL isfifo = FALSE;
 
       /* Always check owner. */
 
@@ -1523,13 +1527,16 @@ if (!isdirectory)
         continue;
         }
 
-      /* An actual file exists. Check that it is a regular file. */
+      /* An actual file exists. Check that it is a regular file, or FIFO
+      if permitted. */
 
-      if ((oldmode & S_IFMT) != S_IFREG)
+      if (ob->allow_fifo && (oldmode & S_IFMT) == S_IFIFO) isfifo = TRUE;
+
+      else if ((oldmode & S_IFMT) != S_IFREG)
         {
         addr->basic_errno = ERRNO_NOTREGULAR;
-        addr->message = string_sprintf("mailbox %s is not a regular file",
-          filename);
+        addr->message = string_sprintf("mailbox %s is not a regular file%s",
+          filename, ob->allow_fifo? " or named pipe" : "");
         addr->special_action = SPECIAL_FREEZE;
         goto RETURN;
         }
@@ -1577,9 +1584,12 @@ if (!isdirectory)
       If the file does not now exist, restart this loop, going back to using
       lstat again. For an NFS error, just defer; other opening errors are
       more serious. The file is opened RDWR so that its format can be checked,
-      and also MBX locking requires the use of a shared (read) lock. */
+      and also MBX locking requires the use of a shared (read) lock. However,
+      a FIFO is opened WRONLY + NDELAY so that it fails if there is no process
+      reading the pipe. */
 
-      fd = open(filename, O_RDWR | O_APPEND, mode);
+      fd = open(filename, isfifo? (O_WRONLY|O_NDELAY) : (O_RDWR|O_APPEND),
+        mode);
       if (fd < 0)
         {
         if (errno == ENOENT)
@@ -1588,7 +1598,12 @@ if (!isdirectory)
           continue;
           }
         addr->basic_errno = errno;
-        if (errno != EWOULDBLOCK)
+        if (isfifo)
+          {
+          addr->message = string_sprintf("while opening named pipe %s "
+            "(could mean no process is reading it)", filename);
+          }
+        else if (errno != EWOULDBLOCK)
           {
           addr->message = string_sprintf("while opening mailbox %s", filename);
           addr->special_action = SPECIAL_FREEZE;
@@ -1627,14 +1642,16 @@ if (!isdirectory)
         goto RETURN;
         }
 
-      /* Check it's still a regular file and the uid, gid, and permissions have
-      not changed. */
+      /* Check it's still a regular file or FIFO, and the uid, gid, and
+      permissions have not changed. */
 
-      if ((statbuf.st_mode & S_IFMT) != S_IFREG)
+      if ((!isfifo && (statbuf.st_mode & S_IFMT) != S_IFREG) ||
+          (isfifo && (statbuf.st_mode & S_IFMT) != S_IFIFO))
         {
         addr->basic_errno = ERRNO_NOTREGULAR;
         addr->message =
-          string_sprintf("opened mailbox %s is not a regular file", filename);
+          string_sprintf("opened mailbox %s is no longer a %s", filename,
+            isfifo? "named pipe" : "regular file");
         addr->special_action = SPECIAL_FREEZE;
         goto RETURN;
         }
